@@ -1,5 +1,5 @@
 # Verilog - Verilog Perl Interface
-# $Id: File.pm 41901 2007-07-16 14:07:31Z wsnyder $
+# $Id: File.pm 41966 2007-07-18 13:59:44Z wsnyder $
 # Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
@@ -22,7 +22,7 @@ use Verilog::Netlist;
 use Verilog::Netlist::Subclass;
 @ISA = qw(Verilog::Netlist::File::Struct
 	Verilog::Netlist::Subclass);
-$VERSION = '3.002';
+$VERSION = '3.010';
 use strict;
 
 structs('new',
@@ -102,6 +102,11 @@ sub module {
     $self->{_cmtref} = $self->{modref};
 }
 
+sub endmodule {
+    my $self = shift;
+    $self->{_cmtref} = undef;  # Assume all module comments are inside the module, not after
+}
+
 sub port {
     my $self = shift;
     my $name = shift;
@@ -202,6 +207,11 @@ sub instant {
     $self->{_cmtref} = $self->{cellref};
 }
 
+sub endcell {
+    my $self = shift;
+    $self->{_cmtref} = $self->{cellref};  # Comments after cell decl go to the cell
+}
+
 sub parampin {
     my $self = shift;
     my $pin = shift;
