@@ -1,5 +1,5 @@
 # Verilog::SigParser.pm -- Verilog signal parsing
-# $Id: SigParser.pm 41901 2007-07-16 14:07:31Z wsnyder $
+# $Id: SigParser.pm 41966 2007-07-18 13:59:44Z wsnyder $
 # Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
@@ -26,7 +26,7 @@ use base qw(Verilog::Parser);
 ######################################################################
 #### Configuration Section
 
-$VERSION = '3.002';
+$VERSION = '3.010';
 
 #######################################################################
 
@@ -73,6 +73,18 @@ sub comment {
 # The my's aren't needed since we do nothing, but are useful if the
 # user copies them from here to their program.
 
+sub endcell {
+    my $self = shift;
+}
+
+sub endtaskfunc {
+    my $self = shift;
+}
+
+sub endmodule {
+    my $self = shift;
+}
+
 sub function {
     my $self = shift;
     my $keyword = shift;
@@ -198,6 +210,21 @@ of each comment line (C<//key rest> to end of line) or comment block
 (C</*key rest */).  It calls C<$self->attribute( meta_text )>
 if the first word has a true value in hash C<$self->metacomment>.
 
+=item $self->endcell ( $token )
+
+This method is called at the end of defining a cell. It is useful for
+writing clean up routines.
+
+=item $self->endtaskfunc ( $token )
+
+This method is called at a endfunction or endtask keyword.  It is useful
+for writing clean up routines.
+
+=item $self->endmodule ( $token )
+
+This method is called at a endmodule keyword. It is useful for writing
+clean up routines.
+
 =item $self->funcsignal ( $keyword, $signame, $vector, $mem, $signed, $value )
 
 This method is called when a signal/variable is declared inside a function.
